#define SQUARE( x ) ( ( x ) * ( x ) )
#define X 0
#define Y 1
#define NO_MUSIC 1
#define NO_SOUND 2
#define CRAZY_COLORS 4
#define BUMPERS 8
#define SKIP_GAME 16

int             game_flags;
int             frame,
                roll;

BITMAP          *buff,
                *lane,
                *pin,
                *pen;
PALETTE         pal;
SAMPLE          *pin_fall,
                *gutter;
MIDI            *music;


struct {
   int          x,
                y;
   float        curve,
                acc[2],
                move[2],
                potential;
   } ball;

typedef struct _PLAYER {
   char         name[20];
   int          handicap,
                total_score,
                score_sheet[2][11];

   struct _PLAYER
                *next;

   } PLAYER;

typedef struct _PIN {
   int          x,
                y,
                fall,
                frame;
   float        acc[2];

   struct _PIN  *next;
   } PIN;


PLAYER          *players;
PIN             *pins;


void init( void ) {
int      midi_driver;

allegro_init( );
install_timer( );
install_mouse( );
install_keyboard( );
install_sound( DIGI_AUTODETECT, MIDI_AUTODETECT, NULL );
set_gfx_mode( GFX_VGA, 320, 200, 0, 0 );

buff = create_bitmap( 320, 200 );

lane = load_bitmap( "lane.bmp", pal );
pin = load_bitmap( "pin.bmp", pal );
pen = load_bitmap( "pencil.bmp", pal );

pin_fall = load_sample( "pin.wav" );
gutter = load_sample( "gutter.wav" );

if( game_flags & CRAZY_COLORS ) {
   int          x;

   srand( time( ) );

   for( x = 0; x < 256; x++ ) {
      pal[x].r = rand()%64;
      pal[x].g = rand()%64;
      pal[x].b = rand()%64;
      }
   }
set_palette( pal );

text_mode( -1 );

}




int polarity( int x ) {

if( x > 0 ) {
   return 1;
   }
if( x < 0 ) {
   return -1;
   }
if( x == 0 ) {
   return 0;
   }
}



void new_player( void ) {
char            name[20];
PLAYER          *tmp;
int             z,
                pos = 0;

players = NULL;
players->next = NULL;

printf( "Enter players' name, press enter when done: \n" );

while( pos < 7 ) {

   printf( "%i.  ", ++pos );

   gets( name );

   if( !strlen( name ) ) {
      return;
      }


   tmp = (PLAYER *)malloc( sizeof( PLAYER ) );

   strcpy( tmp->name, name );
   tmp->total_score = 0;
   tmp->handicap = 0;

   for( z = 0; z < 11; z++ ) {
      tmp->score_sheet[0][z] = 0;
      tmp->score_sheet[1][z] = 0;
      }

   tmp->next = players->next;
   players->next = tmp;

   }

}







void check_params( int argc, char *argv[] ) {
int             x;

game_flags = 0;

for( x = 0; x < argc; x++ ) {

   if( !strcmp( argv[x + 1], "-nomusic" ) ) {
      game_flags += NO_MUSIC;
      }
   else if( !strcmp( argv[x + 1], "-nosound" ) ) {
      game_flags += NO_SOUND;
      }
   else if( !strcmp( argv[x + 1], "-weirdpalette" ) ) {
      game_flags += CRAZY_COLORS;
      }
   else if( !strcmp( argv[x + 1], "-bumpers" ) ) {
      game_flags += BUMPERS;
      }
   else if( !strcmp( argv[x + 1], "-skiptoend" ) ) {
      game_flags += SKIP_GAME;
      }
   else
      if( !( game_flags & NO_MUSIC ) && argv[x + 1] != NULL )
         if( ( music = load_midi( argv[x + 1] ) ) == NULL )
            printf( "MIDI file %s does not exist or is corrupted.\n",
               argv[x + 1] );   
   }
}
